print("import: 'google.api'")
import google.api

print("import: 'google.api.annotations_pb2'")
import google.api.annotations_pb2

print("import: 'google.api.auth_pb2'")
import google.api.auth_pb2

print("import: 'google.api.backend_pb2'")
import google.api.backend_pb2

print("import: 'google.api.billing_pb2'")
import google.api.billing_pb2

print("import: 'google.api.client_pb2'")
import google.api.client_pb2

print("import: 'google.api.config_change_pb2'")
import google.api.config_change_pb2

print("import: 'google.api.consumer_pb2'")
import google.api.consumer_pb2

print("import: 'google.api.context_pb2'")
import google.api.context_pb2

print("import: 'google.api.control_pb2'")
import google.api.control_pb2

print("import: 'google.api.distribution_pb2'")
import google.api.distribution_pb2

print("import: 'google.api.documentation_pb2'")
import google.api.documentation_pb2

print("import: 'google.api.endpoint_pb2'")
import google.api.endpoint_pb2

print("import: 'google.api.field_behavior_pb2'")
import google.api.field_behavior_pb2

print("import: 'google.api.http_pb2'")
import google.api.http_pb2

print("import: 'google.api.httpbody_pb2'")
import google.api.httpbody_pb2

print("import: 'google.api.label_pb2'")
import google.api.label_pb2

print("import: 'google.api.launch_stage_pb2'")
import google.api.launch_stage_pb2

print("import: 'google.api.log_pb2'")
import google.api.log_pb2

print("import: 'google.api.logging_pb2'")
import google.api.logging_pb2

print("import: 'google.api.metric_pb2'")
import google.api.metric_pb2

print("import: 'google.api.monitored_resource_pb2'")
import google.api.monitored_resource_pb2

print("import: 'google.api.monitoring_pb2'")
import google.api.monitoring_pb2

print("import: 'google.api.quota_pb2'")
import google.api.quota_pb2

print("import: 'google.api.resource_pb2'")
import google.api.resource_pb2

print("import: 'google.api.service_pb2'")
import google.api.service_pb2

print("import: 'google.api.source_info_pb2'")
import google.api.source_info_pb2

print("import: 'google.api.system_parameter_pb2'")
import google.api.system_parameter_pb2

print("import: 'google.api.usage_pb2'")
import google.api.usage_pb2

print("import: 'google.longrunning'")
import google.longrunning

print("import: 'google.longrunning.operations_pb2'")
import google.longrunning.operations_pb2

print("import: 'google.longrunning.operations_proto'")
import google.longrunning.operations_proto

print("import: 'google.longrunning.operations_proto_pb2'")
import google.longrunning.operations_proto_pb2

print("import: 'google.protobuf'")
import google.protobuf

print("import: 'google.protobuf.any_pb2'")
import google.protobuf.any_pb2

print("import: 'google.protobuf.api_pb2'")
import google.protobuf.api_pb2

print("import: 'google.protobuf.compiler'")
import google.protobuf.compiler

print("import: 'google.protobuf.compiler.plugin_pb2'")
import google.protobuf.compiler.plugin_pb2

print("import: 'google.protobuf.descriptor'")
import google.protobuf.descriptor

print("import: 'google.protobuf.descriptor_database'")
import google.protobuf.descriptor_database

print("import: 'google.protobuf.descriptor_pb2'")
import google.protobuf.descriptor_pb2

print("import: 'google.protobuf.descriptor_pool'")
import google.protobuf.descriptor_pool

print("import: 'google.protobuf.duration_pb2'")
import google.protobuf.duration_pb2

print("import: 'google.protobuf.empty_pb2'")
import google.protobuf.empty_pb2

print("import: 'google.protobuf.field_mask_pb2'")
import google.protobuf.field_mask_pb2

print("import: 'google.protobuf.internal'")
import google.protobuf.internal

print("import: 'google.protobuf.internal.api_implementation'")
import google.protobuf.internal.api_implementation

print("import: 'google.protobuf.internal.containers'")
import google.protobuf.internal.containers

print("import: 'google.protobuf.internal.decoder'")
import google.protobuf.internal.decoder

print("import: 'google.protobuf.internal.encoder'")
import google.protobuf.internal.encoder

print("import: 'google.protobuf.internal.enum_type_wrapper'")
import google.protobuf.internal.enum_type_wrapper

print("import: 'google.protobuf.internal.message_listener'")
import google.protobuf.internal.message_listener

print("import: 'google.protobuf.internal.python_message'")
import google.protobuf.internal.python_message

print("import: 'google.protobuf.internal.type_checkers'")
import google.protobuf.internal.type_checkers

print("import: 'google.protobuf.internal.well_known_types'")
import google.protobuf.internal.well_known_types

print("import: 'google.protobuf.internal.wire_format'")
import google.protobuf.internal.wire_format

print("import: 'google.protobuf.json_format'")
import google.protobuf.json_format

print("import: 'google.protobuf.message'")
import google.protobuf.message

print("import: 'google.protobuf.message_factory'")
import google.protobuf.message_factory

print("import: 'google.protobuf.proto_builder'")
import google.protobuf.proto_builder

print("import: 'google.protobuf.pyext'")
import google.protobuf.pyext

print("import: 'google.protobuf.reflection'")
import google.protobuf.reflection

print("import: 'google.protobuf.service'")
import google.protobuf.service

print("import: 'google.protobuf.service_reflection'")
import google.protobuf.service_reflection

print("import: 'google.protobuf.source_context_pb2'")
import google.protobuf.source_context_pb2

print("import: 'google.protobuf.struct_pb2'")
import google.protobuf.struct_pb2

print("import: 'google.protobuf.symbol_database'")
import google.protobuf.symbol_database

print("import: 'google.protobuf.text_encoding'")
import google.protobuf.text_encoding

print("import: 'google.protobuf.text_format'")
import google.protobuf.text_format

print("import: 'google.protobuf.timestamp_pb2'")
import google.protobuf.timestamp_pb2

print("import: 'google.protobuf.type_pb2'")
import google.protobuf.type_pb2

print("import: 'google.protobuf.util'")
import google.protobuf.util

print("import: 'google.protobuf.wrappers_pb2'")
import google.protobuf.wrappers_pb2

print("import: 'google.rpc'")
import google.rpc

print("import: 'google.rpc.code_pb2'")
import google.rpc.code_pb2

print("import: 'google.rpc.error_details_pb2'")
import google.rpc.error_details_pb2

print("import: 'google.rpc.status_pb2'")
import google.rpc.status_pb2

print("import: 'google.type'")
import google.type

print("import: 'google.type.calendar_period_pb2'")
import google.type.calendar_period_pb2

print("import: 'google.type.color_pb2'")
import google.type.color_pb2

print("import: 'google.type.date_pb2'")
import google.type.date_pb2

print("import: 'google.type.dayofweek_pb2'")
import google.type.dayofweek_pb2

print("import: 'google.type.expr_pb2'")
import google.type.expr_pb2

print("import: 'google.type.fraction_pb2'")
import google.type.fraction_pb2

print("import: 'google.type.latlng_pb2'")
import google.type.latlng_pb2

print("import: 'google.type.money_pb2'")
import google.type.money_pb2

print("import: 'google.type.postal_address_pb2'")
import google.type.postal_address_pb2

print("import: 'google.type.quaternion_pb2'")
import google.type.quaternion_pb2

print("import: 'google.type.timeofday_pb2'")
import google.type.timeofday_pb2

